==> ideaIC-171.2014.21-sources.jar: org/jetbrains/jps/backwardRefs/BackwardReferenceRegistrar.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.backwardRefs;

import org.jetbrains.jps.javac.ast.api.JavacDef;
import org.jetbrains.jps.javac.ast.api.JavacFileReferencesRegistrar;
import org.jetbrains.jps.javac.ast.api.JavacRef;

import java.util.Collection;
import java.util.List;

public class BackwardReferenceRegistrar implements JavacFileReferencesRegistrar {
  private volatile BackwardReferenceIndexWriter myWriter;

  @Override
  public void initialize() {
    myWriter = BackwardReferenceIndexWriter.getInstance();
  }

  @Override
  public boolean isEnabled() {
    return BackwardReferenceIndexWriter.isEnabled() && BackwardReferenceIndexWriter.getInstance() != null;
  }

  @Override
  public boolean onlyImports() {
    return false;
  }

  @Override
  public void registerFile(String filePath, Collection<JavacRef> refs, List<JavacDef> defs) {
    BackwardReferenceIndexUtil.registerFile(filePath, refs, defs, myWriter);
  }
}

==> ideaIC-173.4301.1-sources.jar: org/jetbrains/jps/backwardRefs/BackwardReferenceRegistrar.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.backwardRefs;

import gnu.trove.TObjectIntHashMap;
import org.jetbrains.jps.javac.ast.api.JavacTypeCast;
import org.jetbrains.jps.javac.ast.api.JavacDef;
import org.jetbrains.jps.javac.ast.api.JavacFileReferencesRegistrar;
import org.jetbrains.jps.javac.ast.api.JavacRef;

import java.util.Collection;

public class BackwardReferenceRegistrar implements JavacFileReferencesRegistrar {
  private volatile BackwardReferenceIndexWriter myWriter;

  @Override
  public void initialize() {
    myWriter = BackwardReferenceIndexWriter.getInstance();
  }

  @Override
  public boolean isEnabled() {
    return BackwardReferenceIndexWriter.isEnabled() && BackwardReferenceIndexWriter.getInstance() != null;
  }

  @Override
  public boolean onlyImports() {
    return false;
  }

  @Override
  public void registerFile(String filePath,
                           TObjectIntHashMap<JavacRef> refs,
                           Collection<JavacDef> defs,
                           Collection<JavacTypeCast> casts) {
    BackwardReferenceIndexUtil.registerFile(filePath, refs, defs, casts, myWriter);
  }
}
